use crate::{
    models::{
        consent::ConsentType,
        item::{ItemFlag, LocationActionType, Pronouns, SkillType},
    },
    static_content::{
        npc::{NPCSayInfo, NPCSayType, NPCSpawnPossession},
        possession_type::PossessionType,
        species::SpeciesType,
    },
};

use super::NPC;

pub fn npc_list() -> Vec<NPC> {
    let ronald_says = vec![NPCSayInfo {
        say_code: "ronald_babble",
        frequency_secs: 10,
        talk_type: NPCSayType::FromFixedList(vec![
            "Under the emperorer I had a whole squadran of security forces at my command... after his fall, I'm relegated to killing trespassers myself.",
            "I once had a whole family going back 4 generations - twenty three people all up - executed because their snotty-nosed child looked at me funny. People feared me in those days. Now they break into my house.",
            "The empire may have crumbled, but my will remains as strong as ever. You trespassers are nothing but pests to be eradicated.",
            "The former emperor entrusted me with the green code share, and I will protect it with my life.",
            "You think you're so clever, entering my home uninvited? I've seen entire families fall to ruin. A trespass here is a grave mistake.",
            "This home is a mere fraction of what I once controlled. You're trespassing in the shadow of greatness, and shall pay.",
            "Your life is forfeit. I'll make an example of your corpses to discourage others from following in your footsteps.",
            "The code I guard is more valuable than all the wealth and resources you could ever dream of, and you shall not have it.",
            "I once had a private army, now I must rely on my wits, my gun and my blade. They have never failed me.",
            "You dare threaten me, the Praefect of a fallen empire? I'll show you what true power is.",
            "Your intrusion is an affront to my dignity. Prepare to face my wrath.",
            "I once commanded an entire praefect, now I must defend myself and my green code share against pathetic invaders like you.",
            "The late emperor trusted me with the green code share, and I will not let it fall into the wrong hands.",
            "My people used to cower in fear of me. Now they dare to trespass on my property.",
            "I once ruled an empire, now I must defend my home and my code against intruders like you.",
            "Your life is forfeit. I'll make sure that this place remains a tomb for your bodies.",
            "I once had an entire military at my command. Now I must defend myself and my code with this gun and blade.",
            "Your trespassing is an insult to my memory and the legacy of the old empire.",
            "Prepare to face the wrath of a Praefect who once commanded the might of an empire in this region.",
            "I'll make sure that your bodies decorate the walls of this home as a warning to others.",
            "Your life is forfeit. I'll make sure that your death serves a purpose - making others fear to be as foolish as you've been coming here.",
            "You dare challenge me, the Praefect of a fallen empire? Prepare to face the barrel of my gun.",
            "I'll make sure that your death is not in vain. I'll use it as an example to deter others from trespassing.",
            "The old empire may be gone, but my determination remains.",
            "You dare enter my home uninvited? Prepare to face the consequences.",
            "Your trespassing is an act of treason against the legacy of the old empire.",
            "I'll make sure that your death serves as a warning to others. This home is not a plaything for trespassers.",
        ]),
    }];

    vec![
        NPC {
            code: "ronalds_house_taipan".to_owned(),
            name: "Brown-headed taipan".to_owned(),
            pronouns: Pronouns::default_inanimate(),
            description: "A large olive coloured snake, its head a darker brown. Its head tracks you as it tastes the air with its forked tongue. As it flicks its tongue, you see a glimpse of two needle-sharp fangs in the front of its mouth".to_owned(),
            spawn_location: "room/ronalds_snakepit".to_owned(),
            aliases: vec!["snake".to_owned(), "taipan".to_owned()],
            aggression: 14,
            aggro_pc_only: true,
            max_health: 24,
            intrinsic_weapon: Some(PossessionType::VenomousFangs),
            total_xp: 15000,
            total_skills: SkillType::values()
                .into_iter()
                .map(|sk| {
                    (
                        sk.clone(),
                        match sk {
                            SkillType::Dodge => 14.0,
                            SkillType::Fists => 19.0,
                            _ => 8.0
                        }
                    )
                })
                .collect(),
            species: SpeciesType::Snake,
            player_consents: vec![ConsentType::Fight],
            ..Default::default()
        },
        NPC {
            code:"ronalds_house_ronald".to_owned(),
            name:"Ronald Fairburn".to_owned(),
            pronouns: Pronouns::default_male(),
            description: "A tall man, probably in his fifties, but still looking fit. His hair shows tinges of gray, while his rugged face and piercing blue eyes give the impression this is a man who would make a heartless decision in an instant".to_owned(),
            spawn_location: "room/ronalds_study".to_owned(),
            spawn_possessions: vec![
                NPCSpawnPossession {
                    what: PossessionType::Z3000Pistol,
                    action_type: LocationActionType::Normal,
                    wear_layer: 0,
                },
                NPCSpawnPossession {
                    what: PossessionType::NinemilFiftyBox,
                    action_type: LocationActionType::Normal,
                    wear_layer: 0,
                },
                NPCSpawnPossession {
                    what: PossessionType::NinemilFiftyBox,
                    action_type: LocationActionType::Normal,
                    wear_layer: 0,
                },
                NPCSpawnPossession {
                    what: PossessionType::Electroblade,
                    action_type: LocationActionType::Wielded,
                    wear_layer: 0,
                },
            ],
            says: ronald_says,
            aggression: 21,
            aggro_pc_only: true,
            max_health: 100,
            total_xp: 20000,
            total_skills: SkillType::values()
                      .into_iter()
                      .map(|sk| {
                          (
                              sk.clone(),
                              match sk {
                                  SkillType::Dodge => 14.0,
                                  SkillType::Blades => 16.0,
                                  SkillType::Pistols => 18.0,
                                  _ => 8.0
                              }
                          )
                      }).collect(),
            species: SpeciesType::Human,
            player_consents: vec!(ConsentType::Fight),
            extra_flags: vec![ItemFlag::EnableCombatAi],
            ..Default::default()
        }
    ]
}
