use super::{PossessionData, WeaponAttackData, WeaponData};
use crate::{
    models::{effect::EffectType, item::SkillType},
    static_content::possession_type::{DamageType, PossessionType},
};
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> = OnceCell::new();
    D.get_or_init(|| {
        vec![
            (
                PossessionType::Fangs,
                PossessionData {
                    weapon_data: Some(WeaponData {
                        uses_skill: SkillType::Fists,
                        raw_min_to_learn: 0.0,
                        raw_max_to_learn: 2.0,
                        normal_attack: WeaponAttackData {
                            start_messages: vec![Box::new(|attacker, victim| {
                                format!(
                                    "{} bares {} teeth and lunges at {}",
                                    &attacker.display_for_sentence(1, true),
                                    &attacker.pronouns.possessive,
                                    &victim.display_for_sentence(1, false),
                                )
                            })],
                            success_messages: vec![Box::new(|attacker, victim, part| {
                                format!(
                                    "{}'s teeth connect and tear at the flesh of {}'s {}",
                                    &attacker.display_for_sentence(1, true),
                                    &victim.display_for_sentence(1, false),
                                    &part.display(victim.sex.clone())
                                )
                            })],
                            ..Default::default()
                        },
                        ..Default::default()
                    }),
                    ..Default::default()
                },
            ),
            (
                PossessionType::VenomousFangs,
                PossessionData {
                    weapon_data: Some(WeaponData {
                        uses_skill: SkillType::Fists,
                        raw_min_to_learn: 0.0,
                        raw_max_to_learn: 2.0,
                        normal_attack: WeaponAttackData {
                            start_messages: vec![Box::new(|attacker, victim| {
                                format!(
                                    "{} lines up {} venomous fang and strikes at {}",
                                    &attacker.display_for_sentence(1, true),
                                    &attacker.pronouns.possessive,
                                    &victim.display_for_sentence(1, false),
                                )
                            })],
                            success_messages: vec![Box::new(|attacker, victim, part| {
                                format!(
                                    "{}'s venomous fang pierces the flesh of {}'s {}",
                                    &attacker.display_for_sentence(1, true),
                                    &victim.display_for_sentence(1, false),
                                    &part.display(victim.sex.clone())
                                )
                            })],
                            base_damage_type: DamageType::Pierce,
                            crit_effects: vec![(0.8, EffectType::SnakePoisoned)],
                            ..Default::default()
                        },
                        ..Default::default()
                    }),
                    ..Default::default()
                },
            ),
            (
                PossessionType::Stinger,
                PossessionData {
                    weapon_data: Some(WeaponData {
                        uses_skill: SkillType::Fists,
                        raw_min_to_learn: 0.0,
                        raw_max_to_learn: 2.0,
                        normal_attack: WeaponAttackData {
                            start_messages: vec![Box::new(|attacker, victim| {
                                format!(
                                    "{} lines up {} stinger to attack {}",
                                    &attacker.display_for_sentence(1, true),
                                    &attacker.pronouns.possessive,
                                    &victim.display_for_sentence(1, false),
                                )
                            })],
                            success_messages: vec![Box::new(|attacker, victim, part| {
                                format!(
                                    "{}'s venomous stinger pierces the flesh of {}'s {}",
                                    &attacker.display_for_sentence(1, true),
                                    &victim.display_for_sentence(1, false),
                                    &part.display(victim.sex.clone())
                                )
                            })],
                            base_damage_type: DamageType::Pierce,
                            crit_effects: vec![(0.8, EffectType::Stung)],
                            ..Default::default()
                        },
                        ..Default::default()
                    }),
                    ..Default::default()
                },
            ),
        ]
    })
}
