use std::collections::BTreeMap;

use super::{DamageType, PossessionData, PossessionType, SoakData, WearData};
use crate::static_content::species::BodyPart;
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> = OnceCell::new();
    &D.get_or_init(|| vec!(
        (
            PossessionType::Jeans,
            PossessionData {
                display: "pair of jeans",
                details: "A fairly plain pair of jeans that probably provides no protection against anything except fashion crimes",
                aliases: vec!["jeans", "pants"],
                weight: 200,
                wear_data: Some(WearData {
                    covers_parts: vec!(BodyPart::Groin,
                                       BodyPart::Legs),
                    thickness: 2.0,
                    dodge_penalty: 0.0,
                    soaks: BTreeMap::new()
                }),
                ..Default::default()
            }
        ),
        (
            PossessionType::LeatherPants,
            PossessionData {
                display: "pair of leather pants",
                details: "Black leather pants that looks like they would protect you from falling off a motorbike, or maybe even offer some protection against certain weapons",
                aliases: vec!("leather pants", "pants"),
                weight: 500,
                wear_data: Some(WearData {
                    covers_parts: vec!(BodyPart::Groin, BodyPart::Legs),
                    thickness: 4.0,
                    dodge_penalty: 0.25,
                    soaks: vec!(
                        (DamageType::Beat,
                         SoakData {
                             min_soak: 1.0,
                             max_soak: 2.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Slash,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Pierce,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                    ).into_iter().collect(),
                }),
                ..Default::default()
            }
        ),
        (
            PossessionType::ShieldWeavePants,
            PossessionData {
                display: "pair of ShieldWeave pants",
                details: "Black pants that look like they could be formal business pants, except they are made out of some kind of light but extremely strong fibre. A label inside says they are ShieldWeave bullet-resistant pants, offering stylish protection against fire from pistols, as well as offering a degree of stab and slash protection",
                aliases: vec!("shield weave pants", "shieldweave pants", "pants"),
                weight: 300,
                wear_data: Some(WearData {
                    covers_parts: vec!(BodyPart::Groin, BodyPart::Legs),
                    thickness: 4.0,
                    dodge_penalty: 0.25,
                    soaks: vec!(
                        (DamageType::Bullet,
                         SoakData {
                             min_soak: 60.0,
                             max_soak: 70.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Slash,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Pierce,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                    ).into_iter().collect(),
                }),
                ..Default::default()
            }
        ),
        (
            PossessionType::CombatBoots,
            PossessionData {
                display: "pair of combat boots",
                details: "A pair of calf-high rough tan-leather combat boots. They look like they would protect the feet",
                aliases: vec!("boots", "footwear", "combat boots"),
                weight: 300,
                wear_data: Some(WearData {
                    covers_parts: vec!(BodyPart::Feet),
                    thickness: 4.0,
                    dodge_penalty: 0.25,
                    soaks: vec!(
                        (DamageType::Beat,
                         SoakData {
                             min_soak: 4.0,
                             max_soak: 5.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Slash,
                         SoakData {
                             min_soak: 3.0,
                             max_soak: 4.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Pierce,
                         SoakData {
                             min_soak: 3.0,
                             max_soak: 4.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Bullet,
                         SoakData {
                             min_soak: 40.0,
                             max_soak: 50.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                    ).into_iter().collect(),
                }),
                ..Default::default()
            }
        ),
    ))
}
