use crate::{
    models::item::LiquidType,
    static_content::{
        fixed_item::FixedItem,
        possession_type::{LiquidContainerData, PossessionData},
    },
};

use super::{Room, SimpleRoom};
use ansi::ansi;
use serde_yaml::from_str as from_yaml_str;

pub fn room_list() -> Vec<Room> {
    from_yaml_str::<Vec<SimpleRoom<()>>>(include_str!("northern_radfields.yaml"))
        .unwrap()
        .into_iter()
        .map(|r| r.into())
        .collect()
}

pub fn fixed_items() -> Vec<FixedItem> {
    vec![
        FixedItem {
            code: "northrad_oasis_billabong".to_owned(),
            name: "billabong".to_owned(),
            description: ansi!("A small body of water of clean-looking fresh water that seems to have been cut into the red earth by an ancient, now gone river. A spring seems to be bubbling away, slowly replenishing the cooling water, leaving the area cooler than the surrounding environment, and creating a relatively green patch of land amongst the scorched desert [Try <bold>drink from billabong<reset> or, if you have a suitable container, <bold>fill<reset> container <bold>from billabong<reset>].").to_owned(),
            location: "room/northrad_i5".to_owned(),
            proper_noun: false,
            aliases: vec!["watering hole".to_owned(), "lake".to_owned(), "spring".to_owned()],
            ..Default::default()
        },
    ]
}

pub fn fixed_item_properties() -> Vec<(&'static str, PossessionData)> {
    vec![(
        "northrad_oasis_billabong",
        PossessionData {
            liquid_container_data: Some(LiquidContainerData {
                capacity: 5000000, // mL
                allowed_contents: Some(vec![LiquidType::Water]),
                ..Default::default()
            }),
            ..Default::default()
        },
    )]
}
