use super::{Room, SimpleRoom};
use crate::{
    models::item::{LiquidType, Scavtype},
    static_content::{
        fixed_item::FixedItem,
        possession_type::{LiquidContainerData, PossessionData, PossessionType},
        scavtable::Scavinfo,
    },
};
use ansi::ansi;
use serde_yaml::from_str as from_yaml_str;

pub fn ronalds_house_scavtable() -> Vec<Scavinfo> {
    vec![Scavinfo {
        possession_type: PossessionType::RustySpike,
        p_present: 1.0,
        difficulty_mean: 7.0,
        difficulty_stdev: 1.0,
        scavtype: Scavtype::Scavenge,
    }]
}

pub fn fixed_items() -> Vec<FixedItem> {
    vec![
        FixedItem {
            code: "ronalds_health_room_fountain".to_owned(),
            name: "water fountain".to_owned(),
            description: ansi!("A large round white stone carved fountain in the centre of the \
                                room. Ornate carved seahorses eject jets of water which \
                                recirculates into a pool of clear water around the outside \
                                of the fountain. The air feels moist here from tiny droplets of water. \
                                [Try <bold>drink from fountain<reset> or, if you have a suitable \
                                container, <bold>fill<reset> container <bold>from fountain<reset>].").to_owned(),
            location: "room/ronalds_health_room".to_owned(),
            proper_noun: false,
            aliases: vec!["fountain".to_owned()],
            ..Default::default()
        },
    ]
}

pub fn fixed_item_properties() -> Vec<(&'static str, PossessionData)> {
    vec![(
        "ronalds_health_room_fountain",
        PossessionData {
            liquid_container_data: Some(LiquidContainerData {
                capacity: 5000000, // mL
                allowed_contents: Some(vec![LiquidType::Water]),
                ..Default::default()
            }),
            ..Default::default()
        },
    )]
}

pub fn room_list() -> Vec<Room> {
    from_yaml_str::<Vec<SimpleRoom<()>>>(include_str!("ronalds_house.yaml"))
        .unwrap()
        .into_iter()
        .map(|r| r.into())
        .collect()
}
